@@ -19,6 +19,7 @@ import bs4
 from indic_transliteration import sanscript
 
 from .utils import validate_scheme, transliterate_between
+from .constants import INTERNAL_SCHEME, DEFAULT_SCHEME
 
 ###############################################################################
 
@@ -26,11 +27,6 @@ LOGGER = logging.getLogger(__name__)
 
 ###############################################################################
 
-INTERNAL_SCHEME = sanscript.SLP1
-DEFAULT_SCHEME = sanscript.DEVANAGARI
-
-###############################################################################
-
 
 class Lexicon(Model):
     """Lexicon Model"""
@@ -129,8 +125,18 @@ class Entry:
 
     @lru_cache(maxsize=1)
     def meaning(self):
+        """Extract meaning of the entry"""
         return self._body.get_text().strip()
 
+    def to_dict(self):
+        """Get a python `dict` representation of the entry"""
+        return {
+            "id": str(self.id),
+            "key": self.key,
+            "data": self.data,
+            "text": self.meaning()
+        }
+
     def parse(self):
         raise NotImplementedError
 
